@@ -294,17 +294,19 @@ void MainWindow::updateValues(float value){
         logIndex++;
     }
 
-    if(vol > triggerValue && process == NULL){
-        if(triggerCount >= triggerCountSetting){
-            process = new QProcess();
-            connect(process, SIGNAL(finished(int)), this, SLOT(processFinished()));
-            process->start(triggerCommand);
-            triggerCount = 0;
+    if(triggerValue != 0){
+        if(vol > triggerValue && process == NULL){
+            if(triggerCount >= triggerCountSetting){
+                process = new QProcess();
+                connect(process, SIGNAL(finished(int)), this, SLOT(processFinished()));
+                process->start(triggerCommand);
+                triggerCount = 0;
+            }else{
+                triggerCount++;
+            }
         }else{
-            triggerCount++;
+            triggerCount = 0;
         }
-    }else{
-        triggerCount = 0;
     }
 
     volumeMeterWidget->updateValue(vol);
