@@ -29,9 +29,13 @@
 #define MAX_LINEAR 200
 #define RATIO 3.
 
+/**
+ * Base class for all volume displays.
+ */
 class VolumeMeterWidget : public QGLWidget
 {
     Q_OBJECT
+
 public:
     explicit VolumeMeterWidget(QWidget *parent = 0);
     ~VolumeMeterWidget();
@@ -45,16 +49,27 @@ public:
     void setUseColoredScale(bool b);
 
 signals:
+    /**
+     * This signal is triggered on a mouse release event.
+     */
     void clicked();
 
 protected:
+    /** QImage for holding the widgets background.
+     *
+     * This image is used to cache the non moving parts of the display.
+     * The idea is to paint the background only when needed in order to improve the performance.
+     * Ideally, the background is only re-painted on size changes.
+     */
     QImage          *background;
     int             currentValue;
     bool            dbUnit;
+    /** Height of the widget */
     float           h;
     Qt::GlobalColor triggerIndicatorColor;
     int             triggerValue;
     bool            useColoredScale;
+    /** Width of the widget */
     float           w;
 
     int             lowerThreshold;
@@ -64,18 +79,51 @@ protected:
     QColor          midColor;
     QColor          upperColor;
 
+
+    /**
+     * Calculate the current size of the widget.
+     *
+     * Calculates the widget size taking the aspect ration into account.
+     * The size will be calculated such that the displayed widget fits
+     * into the available space without being deformed.
+     * This method sets the h and w variables.
+     */
     virtual void calculateSize();
 
+    /**
+     * Method for drawing the widgets content.
+     *
+     * This is a pure virtual function that has to be implemented by all subclasses.
+     * This method is responsible for painting the widgets content.
+     */
     virtual void draw(QPainter *painter) = 0;
     virtual void drawBackground(QPainter *painter);
     virtual void drawTriggerIndicator(QPainter *painter);
 
+    /**
+     * Initialize the QImage which holds the background.
+     */
     virtual void initBackground();
+    /**
+     * Initialize the painter.
+     *
+     * This method sets the viewport, window etc.
+     */
     virtual void initPainter(QPainter *painter);
-    void mouseReleaseEvent(QMouseEvent *);
+    /**
+     * Method used to trigger the @ref VolumeMeterWidget#clicked() signal.
+     */
+    virtual void mouseReleaseEvent(QMouseEvent *);
     virtual void paintEvent(QPaintEvent *event);
 
+    /**
+     * Prepare the background.
+     *
+     * Draws the background on a QImage.
+     * @see VolumeMeterWidget#background
+     */
     virtual void prepareBackground();
+
     virtual void resizeEvent(QResizeEvent *event);
 };
 
